@@ -10,10 +10,10 @@ except ImportError:
 
 from .core import LLM, Storage, Tool, ToolResult
 from .core.agent import Agent
-from .core.exceptions import AgentError, CogencyError, ProfileError, ProviderError, ToolError
+from .core.exceptions import AgentError, CogencyError, ProfileError, ProviderError
 from .tools import tools
 
-__version__ = "3.0.1"
+__version__ = "3.1.0"
 __all__ = [
     "Agent",
     "AgentError",
@@ -23,7 +23,6 @@ __all__ = [
     "ProviderError",
     "Storage",
     "Tool",
-    "ToolError",
     "ToolResult",
     "tools",
 ]
