@@ -13,19 +13,15 @@ async def execute_tool(
 
     tool = next((t for t in execution.tools if t.name == tool_name), None)
     if not tool:
-        return ToolResult(outcome=f"{tool_name} not found: Tool '{tool_name}' not registered")
+        return ToolResult(outcome=f"Tool '{tool_name}' not registered", error=True)
 
     args = dict(call.args)
 
-    # Inject runtime execution context
-    args["base_dir"] = execution.base_dir
+    args["sandbox_dir"] = execution.sandbox_dir
     args["access"] = execution.access
 
-    # Tool-specific params
     if tool_name == "shell":
         args["timeout"] = execution.shell_timeout
-    if tool_name == "web_scrape":
-        args["scrape_limit"] = execution.scrape_limit
     if user_id:
         args["user_id"] = user_id
 
