@@ -18,18 +18,7 @@ def tool_instructions(tools: list[Tool]) -> str:
             param_str = ", ".join(params)
             lines.append(f"{tool.name}({param_str}) - {tool.description}")
 
-    return "TOOLBOX:\n" + "\n".join(lines)
-
-
-def format_call_human(call: ToolCall) -> str:
-    """Format tool call for human display - semantic action."""
-    from . import tools
-
-    tool_instance = tools.get(call.name)
-    if not tool_instance:
-        return f"Tool {call.name} not available"
-
-    return tool_instance.describe(call.args)
+    return "TOOLS:\n" + "\n".join(lines)
 
 
 def format_call_agent(call: ToolCall) -> str:
@@ -37,13 +26,8 @@ def format_call_agent(call: ToolCall) -> str:
     return json.dumps({"name": call.name, "args": call.args})
 
 
-def format_result_human(result: ToolResult) -> str:
-    """Format tool result for human display - clean outcome."""
-    return result.outcome
-
-
 def format_result_agent(result: ToolResult) -> str:
     """Format tool result for agent consumption - outcome + full content."""
     if result.content:
-        return f"{result.outcome}\n\n{result.content}"
+        return f"{result.outcome}\n{result.content}"
     return result.outcome
