@@ -10,20 +10,25 @@ class ToolRegistry:
         self._register_builtins()
 
     def _register_builtins(self):
-        from .file import FileEdit, FileList, FileRead, FileSearch, FileWrite
-        from .memory import MemoryRecall
-        from .system import SystemShell
-        from .web import WebScrape, WebSearch
+        from .code.edit import Edit
+        from .code.grep import Grep
+        from .code.ls import Ls
+        from .code.read import Read
+        from .code.shell import Shell
+        from .code.write import Write
+        from .memory.recall import Recall
+        from .web.scrape import Scrape
+        from .web.search import Search
 
-        self.register(FileRead(), "file")
-        self.register(FileWrite(), "file")
-        self.register(FileEdit(), "file")
-        self.register(FileList(), "file")
-        self.register(FileSearch(), "file")
-        self.register(SystemShell(), "system")
-        self.register(WebScrape(), "web")
-        self.register(WebSearch(), "web")
-        self.register(MemoryRecall(), "memory")
+        self.register(Read(), "code")
+        self.register(Write(), "code")
+        self.register(Edit(), "code")
+        self.register(Ls(), "code")
+        self.register(Grep(), "code")
+        self.register(Shell(), "code")
+        self.register(Scrape(), "web")
+        self.register(Search(), "web")
+        self.register(Recall(), "memory")
 
     def register(self, tool_instance: Tool, category: str):
         if not isinstance(tool_instance, Tool):
@@ -39,8 +44,13 @@ class ToolRegistry:
         self.by_name[tool_instance.name] = type(tool_instance)
 
     def __call__(self) -> list[Tool]:
-        classes = {c for cat_classes in self.by_category.values() for c in cat_classes}
-        return [cls() for cls in classes]
+        seen = set()
+        return [
+            cls()
+            for cat_classes in self.by_category.values()
+            for cls in cat_classes
+            if not (cls in seen or seen.add(cls))
+        ]
 
     def category(self, categories: str | list[str]) -> list[Tool]:
         if isinstance(categories, str):
